@@ -1,5 +1,6 @@
 import torch
 import os
+import io
 import json
 import pandas as pd
 import numpy as np
@@ -928,8 +929,11 @@ class BertTagger:
         directory = directory = os.path.dirname(path)
         self._make_dir(directory)
 
+        buffer = io.BytesIO()
+        torch.save(self.model, buffer)
+
         to_save = {"tagger_conf": self.config.to_dict(),
-                   "model": self.model}
+                   "model": buffer}
 
         with open(path, "wb") as f:
             dill.dump(to_save, f)
@@ -941,7 +945,16 @@ class BertTagger:
     def _set_loaded_values(self, loaded):
         """ Use loaded configuration values.
         """
-        self.model = loaded["model"]
+
+        if isinstance(loaded["model"], io.BytesIO):
+            buffer = loaded["model"]
+            buffer.seek(0)
+            self.model = torch.load(buffer, map_location=self.device)
+
+        # Make it compatible with older models
+        else:
+            self.model = loaded["model"]
+
         self.config.update_bulk(loaded["tagger_conf"])
 
         # Assign model to current device
@@ -958,7 +971,10 @@ class BertTagger:
         ModelExistingValidator().validate_saved_model(path)
 
         with open(path, "rb") as f:
-            loaded = dill.load(f)
+            try:
+                loaded = dill.load(f)
+            except RuntimeError:
+                raise exceptions.IncompatibleVersionAndDeviceError(f"The models trained on texta-bert-tagger version <=2.2.0 cannot be loaded onto device '{self.device_type}' if they were trained on another type of device.")
 
         self._set_loaded_values(loaded)
         return True
